@@ -76,7 +76,10 @@ describe 'horizon' do
           'API_RESULT_LIMIT = 1000',
           'TIME_ZONE = "UTC"',
           'COMPRESS_OFFLINE = True',
-          "FILE_UPLOAD_TEMP_DIR = '/tmp'"
+          "FILE_UPLOAD_TEMP_DIR = '/tmp'",
+          "OPENSTACK_HEAT_STACK = {",
+          "    'enable_user_pass': True",
+          "}",
         ])
 
         # From internals of verify_contents, get the contents to check for absence of a line
@@ -112,7 +115,6 @@ describe 'horizon' do
           :neutron_options                => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
                                             'enable_distributed_router' => false, 'enable_ha_router' => false, 'profile_support' => 'cisco',
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
-          :instance_options               => {'disable_image' => true, 'disable_instance_snapshot' => true, 'disable_volume' => true, 'disable_volume_snapshot' => true, 'create_volume' => false },
           :file_upload_temp_dir           => '/var/spool/horizon',
           :secure_cookies                 => true,
           :api_versions                   => {'identity' => 2.0},
@@ -128,7 +130,6 @@ describe 'horizon' do
           :default_theme                  => 'default',
           :password_autocomplete          => 'on',
           :images_panel                   => 'angular',
-          :create_image_defaults          => {'image_visibility' => 'private'},
           :password_retrieve              => true,
           :enable_secure_proxy_ssl_header => true,
         })
@@ -177,15 +178,6 @@ describe 'horizon' do
           "    'supported_provider_types': ['flat', 'vxlan'],",
           "    'supported_vnic_types': ['*'],",
           'OPENSTACK_ENABLE_PASSWORD_RETRIEVE = True',
-          'CREATE_IMAGE_DEFAULTS = {',
-          "    'image_visibility': 'private',",
-          "    'config_drive': False,",
-          "    'create_volume': False,",
-          "    'disable_image': True,",
-          "    'disable_instance_snapshot': True,",
-          "    'disable_volume': True,",
-          "    'disable_volume_snapshot': True,",
-          "    'enable_scheduler_hints': True,",
           'OPENSTACK_ENDPOINT_TYPE = "internalURL"',
           'SECONDARY_ENDPOINT_TYPE = "ANY-VALUE"',
           'API_RESULT_LIMIT = 4682',
@@ -210,6 +202,19 @@ describe 'horizon' do
       it { is_expected.to contain_file(params[:file_upload_temp_dir]) }
     end
 
+    context 'with enable_user_pass disabled' do
+      before do
+        params.merge!({ :enable_user_pass => false })
+      end
+      it {
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          "OPENSTACK_HEAT_STACK = {",
+          "    'enable_user_pass': False",
+          "}",
+        ])
+      }
+    end
+
     context 'with overridden parameters and cache_server_ip array' do
       before do
         params.merge!({
@@ -521,69 +526,6 @@ describe 'horizon' do
                                         ])
       end
     end
-
-    context 'with customization_module provided' do
-      before do
-        params.merge!({
-          :help_url                => 'https://docs.openstack.org',
-          :customization_module    => 'my_project.overrides',
-          :local_settings_template => fixtures_path + '/override_local_settings.py.erb'
-        })
-      end
-
-      it 'uses the custom local_settings.py template' do
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          '# Custom local_settings.py',
-          "HORIZON_CONFIG = {",
-          "    'dashboards': ('project', 'admin', 'settings',),",
-          "    'default_dashboard': 'project',",
-          "    'user_home': 'openstack_dashboard.views.get_user_home',",
-          "    'ajax_queue_limit': 10,",
-          "    'auto_fade_alerts': {",
-          "        'delay': 3000,",
-          "        'fade_duration': 1500,",
-          "        'types': ['alert-success', 'alert-info']",
-          "    },",
-          "    'help_url': \"https://docs.openstack.org\",",
-          "    'exceptions': {'recoverable': exceptions.RECOVERABLE,",
-          "                   'not_found': exceptions.NOT_FOUND,",
-          "                   'unauthorized': exceptions.UNAUTHORIZED},",
-          "    'customization_module': 'my_project.overrides',",
-          "}",
-        ])
-      end
-    end
-
-    context 'with customization_module empty' do
-      before do
-        params.merge!({
-          :help_url                => 'https://docs.openstack.org',
-          :customization_module    => '',
-          :local_settings_template => fixtures_path + '/override_local_settings.py.erb'
-        })
-      end
-
-      it 'uses the custom local_settings.py template' do
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          '# Custom local_settings.py',
-          "HORIZON_CONFIG = {",
-          "    'dashboards': ('project', 'admin', 'settings',),",
-          "    'default_dashboard': 'project',",
-          "    'user_home': 'openstack_dashboard.views.get_user_home',",
-          "    'ajax_queue_limit': 10,",
-          "    'auto_fade_alerts': {",
-          "        'delay': 3000,",
-          "        'fade_duration': 1500,",
-          "        'types': ['alert-success', 'alert-info']",
-          "    },",
-          "    'help_url': \"https://docs.openstack.org\",",
-          "    'exceptions': {'recoverable': exceptions.RECOVERABLE,",
-          "                   'not_found': exceptions.NOT_FOUND,",
-          "                   'unauthorized': exceptions.UNAUTHORIZED},",
-          "}",
-        ])
-      end
-    end
   end
 
   shared_examples_for 'horizon on RedHat' do
